@@ -12,7 +12,7 @@ use Digest              ();
 use overload            ();
 use Object::Signature   ();
 
-our $VERSION = "0.12";
+our $VERSION = "0.13";
 
 my @session_data_accessors; # used in delete_session
 BEGIN {
@@ -99,14 +99,14 @@ sub finalize {
 sub finalize_session {
     my $c = shift;
 
+    $c->NEXT::finalize_session;
+
     $c->_save_session_id;
     $c->_save_session;
     $c->_save_flash;
     $c->_save_session_expires;
 
     $c->_clear_session_instance_data;
-
-    $c->NEXT::finalize_session;
 }
 
 sub _save_session_id {
@@ -261,7 +261,7 @@ sub _clear_session_instance_data {
 sub delete_session {
     my ( $c, $msg ) = @_;
 
-    $c->log->debug("Deleting session") if $c->debug;
+    $c->log->debug("Deleting session" . ( defined($msg) ? "($msg)" : '(no reason given)') ) if $c->debug;
 
     # delete the session data
     if ( my $sid = $c->sessionid ) {
@@ -388,6 +388,15 @@ sub flash {
     }
 }
 
+sub clear_flash {
+    my $c = shift;
+    
+    #$c->delete_session_data("flash:" . $c->sessionid); # should this be in here? or delayed till finalization?
+    $c->_flash_key_hashes({});
+    $c->_flash_keep_keys({});
+    $c->_flash({});
+}
+
 sub session_expire_key {
     my ( $c, %keys ) = @_;
 
@@ -639,6 +648,10 @@ of every request.
         }
     }
 
+=item clear_flash
+
+Zap all the keys in the flash regardless of their current state.
+
 =item keep_flash @keys
 
 If you wawnt to keep a flash key for the next request too, even if it hasn't
